@@ -21,10 +21,10 @@ try:
 except ImportError:
     asyncio = None
 
-from concurrent import futures
 import sys
 import threading
 
+from concurrent import futures
 from time import monotonic as now
 import six
 
@@ -73,10 +73,10 @@ from tenacity import _utils
 
 
 def retry(*dargs, **dkw):
-    """Decorator function that wraps + instantiates a ``Retrying`` object.
+    """Wrap a function with a new `Retrying` object.
 
-    @param *dargs: positional arguments passed to Retrying object
-    @param **dkw: keyword arguments passed to the Retrying object
+    :param dargs: positional arguments passed to Retrying object
+    :param dkw: keyword arguments passed to the Retrying object
     """
     # support both @retry and @retry() as valid syntax
     if len(dargs) == 1 and callable(dargs[0]):
@@ -111,11 +111,13 @@ class DoSleep(float):
 class BaseRetrying(object):
 
     def __init__(self,
+                 sleep=sleep,
                  stop=stop_never, wait=wait_none(),
                  retry=retry_if_exception_type(),
                  before=before_nothing,
                  after=after_nothing,
                  reraise=False):
+        self.sleep = sleep
         self.stop = stop
         self.wait = wait
         self.retry = retry
@@ -135,7 +137,7 @@ class BaseRetrying(object):
 
     @property
     def statistics(self):
-        """A dictionary of runtime statistics this controller has gathered.
+        """Return a dictionary of runtime statistics.
 
         This dictionary will be empty when the controller has never been
         ran. When it is running or has ran previously it should have (but
@@ -230,12 +232,6 @@ class BaseRetrying(object):
 class Retrying(BaseRetrying):
     """Retrying controller."""
 
-    def __init__(self,
-                 sleep=sleep,
-                 **kwargs):
-        super(Retrying, self).__init__(**kwargs)
-        self.sleep = sleep
-
     def call(self, fn, *args, **kwargs):
         self.begin(fn)
 
@@ -277,7 +273,7 @@ class Future(futures.Future):
 
     @classmethod
     def construct(cls, attempt_number, value, has_exception):
-        """Helper (for testing) for making these objects easily."""
+        """Construct a new Future object."""
         fut = cls(attempt_number)
         if has_exception:
             fut.set_exception(value)
